@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
    The maintainer is reachable by electronic mail at daved@physiol.usyd.edu.au
 =============================================================================*/
@@ -53,8 +53,7 @@ extern int simulate_allcaps;
 extern int simulate_smallcaps;
 
 
-#define MAX_ATTRS (1000)
-
+#define MAX_ATTRS (10000)
 
 
 /* For each RTF text block (the text within braces) we must keep
@@ -65,12 +64,11 @@ extern int simulate_smallcaps;
  * their parent AttrStack.
  */
 typedef struct _stack {
-	unsigned char attr_stack [MAX_ATTRS];
-	char *attr_stack_params [MAX_ATTRS]; 
+	unsigned char attr_stack[MAX_ATTRS];
+	char *attr_stack_params[MAX_ATTRS]; 
 	int tos;
 	struct _stack *next;
-}
-AttrStack;
+} AttrStack;
 
 static AttrStack *stack_of_stacks = NULL;
 static AttrStack *stack_of_stacks_top = NULL;
@@ -90,10 +88,10 @@ attr_express_begin (int attr, char* param) {
 	switch(attr) 
 	{
 	case ATTR_BOLD: 
-		printf (op->bold_begin); 
+		printf(op->bold_begin); 
 		break;
 	case ATTR_ITALIC: 
-		printf (op->italic_begin); 
+		printf(op->italic_begin); 
 		break;
 
 	/* Various underlines, they all resolve to HTML's <u> */
@@ -105,11 +103,11 @@ attr_express_begin (int attr, char* param) {
 	case ATTR_2DOT_DASH_UL:
 	case ATTR_WORD_UL: 
 	case ATTR_UNDERLINE: 
-		printf (op->underline_begin); 
+		printf(op->underline_begin); 
 		break;
 
 	case ATTR_DOUBLE_UL: 
-		printf (op->dbl_underline_begin); 
+		printf(op->dbl_underline_begin); 
 		break;
 
 	case ATTR_FONTSIZE: 
@@ -117,48 +115,48 @@ attr_express_begin (int attr, char* param) {
 		break;
 
 	case ATTR_FONTFACE: 
-		printf (op->font_begin,param); 
+		printf(op->font_begin,param); 
 		break;
 
 	case ATTR_FOREGROUND: 
-		printf (op->foreground_begin, param); 
+		printf(op->foreground_begin, param); 
 		break;
 
 	case ATTR_BACKGROUND: 
 		if (!simple_mode)
-		  printf (op->foreground_begin,param); 
+		  printf(op->foreground_begin,param); 
 		break;
 
 	case ATTR_SUPER: 
-		printf (op->superscript_begin); 
+		printf(op->superscript_begin); 
 		break;
 	case ATTR_SUB: 
-		printf (op->subscript_begin); 
+		printf(op->subscript_begin); 
 		break;
 
 	case ATTR_STRIKE: 
-		printf (op->strikethru_begin); 
+		printf(op->strikethru_begin); 
 		break;
 
 	case ATTR_DBL_STRIKE: 
-		printf (op->dbl_strikethru_begin); 
+		printf(op->dbl_strikethru_begin); 
 		break;
 
 	case ATTR_EXPAND: 
-		printf (op->expand_begin, param); 
+		printf(op->expand_begin, param); 
 		break;
 
 	case ATTR_OUTLINE: 
-		printf (op->outline_begin); 
+		printf(op->outline_begin); 
 		break;
 	case ATTR_SHADOW: 
-		printf (op->shadow_begin); 
+		printf(op->shadow_begin); 
 		break;
 	case ATTR_EMBOSS: 
-		printf (op->emboss_begin); 
+		printf(op->emboss_begin); 
 		break;
 	case ATTR_ENGRAVE: 
-		printf (op->engrave_begin); 
+		printf(op->engrave_begin); 
 		break;
 
 	case ATTR_CAPS:
@@ -171,7 +169,7 @@ attr_express_begin (int attr, char* param) {
 			simulate_smallcaps = TRUE;
 		else {
 			if (op->small_caps_begin)
-				printf (op->small_caps_begin); 
+				printf(op->small_caps_begin); 
 		}
 		break;
 	}
@@ -191,10 +189,10 @@ attr_express_end (int attr, char *param)
 	switch(attr) 
 	{
 	case ATTR_BOLD: 
-		printf (op->bold_end); 
+		printf(op->bold_end); 
 		break;
 	case ATTR_ITALIC: 
-		printf (op->italic_end); 
+		printf(op->italic_end); 
 		break;
 
 	/* Various underlines, they all resolve to HTML's </u> */
@@ -206,11 +204,11 @@ attr_express_end (int attr, char *param)
 	case ATTR_2DOT_DASH_UL: 
 	case ATTR_WORD_UL: 
 	case ATTR_UNDERLINE: 
-		printf (op->underline_end); 
+		printf(op->underline_end); 
 		break;
 
 	case ATTR_DOUBLE_UL: 
-		printf (op->dbl_underline_end); 
+		printf(op->dbl_underline_end); 
 		break;
 
 	case ATTR_FONTSIZE: 
@@ -218,47 +216,47 @@ attr_express_end (int attr, char *param)
 		break;
 
 	case ATTR_FONTFACE: 
-		printf (op->font_end); 
+		printf(op->font_end); 
 		break;
 
 	case ATTR_FOREGROUND: 
-		printf (op->foreground_end); 
+		printf(op->foreground_end); 
 		break;
 	case ATTR_BACKGROUND: 
 		if (!simple_mode)
-		  printf (op->background_end);
+		  printf(op->background_end);
 		break;
 
 	case ATTR_SUPER: 
-		printf (op->superscript_end); 
+		printf(op->superscript_end); 
 		break;
 	case ATTR_SUB: 
-		printf (op->subscript_end); 
+		printf(op->subscript_end); 
 		break;
 
 	case ATTR_STRIKE: 
-		printf (op->strikethru_end); 
+		printf(op->strikethru_end); 
 		break;
 
 	case ATTR_DBL_STRIKE: 
-		printf (op->dbl_strikethru_end); 
+		printf(op->dbl_strikethru_end); 
 		break;
 
 	case ATTR_OUTLINE: 
-		printf (op->outline_end); 
+		printf(op->outline_end); 
 		break;
 	case ATTR_SHADOW: 
-		printf (op->shadow_end); 
+		printf(op->shadow_end); 
 		break;
 	case ATTR_EMBOSS: 
-		printf (op->emboss_end); 
+		printf(op->emboss_end); 
 		break;
 	case ATTR_ENGRAVE: 
-		printf (op->engrave_end); 
+		printf(op->engrave_end); 
 		break;
 
 	case ATTR_EXPAND: 
-		printf (op->expand_end); 
+		printf(op->expand_end); 
 		break;
 
 	case ATTR_CAPS:
@@ -271,7 +269,7 @@ attr_express_end (int attr, char *param)
 			simulate_smallcaps = FALSE;
 		else {
 			if (op->small_caps_end)
-				printf (op->small_caps_end); 
+				printf(op->small_caps_end); 
 		}
 		break;
 	}
@@ -291,11 +289,14 @@ attr_push(int attr, char* param)
 {
 	AttrStack *stack = stack_of_stacks_top;
 	if (!stack) {
-		warning_handler ("no stack to push attribute onto");
+		warning_handler("No stack to push attribute onto");
 		return;
 	}
 
-	if (stack->tos>=MAX_ATTRS) { fprintf (stderr,"Too many attributes!\n"); return; }
+	if (stack->tos >= MAX_ATTRS) {
+		fprintf(stderr, "Too many attributes!\n");
+		return;
+	}
 
 	/* Make sure it's understood we're in the <body> section. */
 	/* KLUDGE */
@@ -303,13 +304,13 @@ attr_push(int attr, char* param)
 	starting_text();
 
 	++stack->tos;
-	stack->attr_stack [stack->tos]=attr;
+	stack->attr_stack[stack->tos] = attr;
 	if (param) 
-		stack->attr_stack_params [stack->tos]=my_strdup(param);
+		stack->attr_stack_params[stack->tos] = my_strdup(param);
 	else
-		stack->attr_stack_params [stack->tos]=NULL;
+		stack->attr_stack_params[stack->tos] = NULL;
 
-	attr_express_begin (attr, param);
+	attr_express_begin(attr, param);
 }
 
 
@@ -390,7 +391,7 @@ attrstack_push ()
 	AttrStack *prev_stack;
 
 	new_stack = (AttrStack*) my_malloc (sizeof (AttrStack));
-	bzero ((void*) new_stack, sizeof (AttrStack));
+	memset ((void*) new_stack, 0, sizeof (AttrStack));
 
 	prev_stack = stack_of_stacks_top;
 
