@@ -36,10 +36,9 @@
 
 
 #include <stdio.h>
-#if linux || __DJGPP__ /* daved - 0.19.0,  st001906 - 0.19.6 */
 #include <stdlib.h>
-#endif
 #include <string.h>
+
 #include "malloc.h"
 #include "defs.h"
 #include "error.h"
@@ -64,7 +63,7 @@ op_create ()
 	if (!new_op)
 		error_handler ("cannot allocate output personality");
 
-	bzero ((void*) new_op, sizeof (OutputPersonality));
+	memset ((void*) new_op, 0, sizeof (OutputPersonality));
 	return new_op;
 }
 
